import typing_extensions

from data_repo_client.paths import PathValues
from data_repo_client.apis.paths.status import Status
from data_repo_client.apis.paths.configuration import Configuration
from data_repo_client.apis.paths.shutdown import Shutdown
from data_repo_client.apis.paths.api_resources_v1_profiles import ApiResourcesV1Profiles
from data_repo_client.apis.paths.api_resources_v1_profiles_id import ApiResourcesV1ProfilesId
from data_repo_client.apis.paths.api_resources_v1_profiles_id_policies import ApiResourcesV1ProfilesIdPolicies
from data_repo_client.apis.paths.api_resources_v1_profiles_id_policies_policy_name_members import ApiResourcesV1ProfilesIdPoliciesPolicyNameMembers
from data_repo_client.apis.paths.api_resources_v1_profiles_id_policies_policy_name_members_member_email import ApiResourcesV1ProfilesIdPoliciesPolicyNameMembersMemberEmail
from data_repo_client.apis.paths.api_repository_v1_snapshots import ApiRepositoryV1Snapshots
from data_repo_client.apis.paths.api_repository_v1_snapshots_role_map import ApiRepositoryV1SnapshotsRoleMap
from data_repo_client.apis.paths.api_repository_v1_snapshots_id import ApiRepositoryV1SnapshotsId
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_summary import ApiRepositoryV1SnapshotsIdSummary
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_data_table import ApiRepositoryV1SnapshotsIdDataTable
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_export import ApiRepositoryV1SnapshotsIdExport
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_files_fileid import ApiRepositoryV1SnapshotsIdFilesFileid
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_filesystem_objects import ApiRepositoryV1SnapshotsIdFilesystemObjects
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_policies import ApiRepositoryV1SnapshotsIdPolicies
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_policies_policy_name_members import ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembers
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_policies_policy_name_members_member_email import ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembersMemberEmail
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_roles import ApiRepositoryV1SnapshotsIdRoles
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_link_duos_dataset_duos_id import ApiRepositoryV1SnapshotsIdLinkDuosDatasetDuosId
from data_repo_client.apis.paths.api_repository_v1_snapshots_id_unlink_duos_dataset import ApiRepositoryV1SnapshotsIdUnlinkDuosDataset
from data_repo_client.apis.paths.api_repository_v1_duos import ApiRepositoryV1Duos
from data_repo_client.apis.paths.api_repository_v1_duos_duos_id import ApiRepositoryV1DuosDuosId
from data_repo_client.apis.paths.api_repository_v1_duos_duos_id_sync_authorized_users import ApiRepositoryV1DuosDuosIdSyncAuthorizedUsers
from data_repo_client.apis.paths.api_repository_v1_datasets import ApiRepositoryV1Datasets
from data_repo_client.apis.paths.api_repository_v1_datasets_id import ApiRepositoryV1DatasetsId
from data_repo_client.apis.paths.api_repository_v1_datasets_id_summary import ApiRepositoryV1DatasetsIdSummary
from data_repo_client.apis.paths.api_repository_v1_datasets_id_policies import ApiRepositoryV1DatasetsIdPolicies
from data_repo_client.apis.paths.api_repository_v1_datasets_id_policies_policy_name_members import ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembers
from data_repo_client.apis.paths.api_repository_v1_datasets_id_policies_policy_name_members_member_email import ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembersMemberEmail
from data_repo_client.apis.paths.api_repository_v1_datasets_id_roles import ApiRepositoryV1DatasetsIdRoles
from data_repo_client.apis.paths.api_repository_v1_datasets_id_ingest import ApiRepositoryV1DatasetsIdIngest
from data_repo_client.apis.paths.api_repository_v1_datasets_id_update_schema import ApiRepositoryV1DatasetsIdUpdateSchema
from data_repo_client.apis.paths.api_repository_v1_datasets_id_transactions import ApiRepositoryV1DatasetsIdTransactions
from data_repo_client.apis.paths.api_repository_v1_datasets_id_transactions_transaction_id import ApiRepositoryV1DatasetsIdTransactionsTransactionId
from data_repo_client.apis.paths.api_repository_v1_datasets_id_assets import ApiRepositoryV1DatasetsIdAssets
from data_repo_client.apis.paths.api_repository_v1_datasets_id_assets_assetid import ApiRepositoryV1DatasetsIdAssetsAssetid
from data_repo_client.apis.paths.api_repository_v1_datasets_id_deletes import ApiRepositoryV1DatasetsIdDeletes
from data_repo_client.apis.paths.api_repository_v1_register_user import ApiRepositoryV1RegisterUser
from data_repo_client.apis.paths.api_repository_v1_datasets_id_files import ApiRepositoryV1DatasetsIdFiles
from data_repo_client.apis.paths.api_repository_v1_datasets_id_files_bulk import ApiRepositoryV1DatasetsIdFilesBulk
from data_repo_client.apis.paths.api_repository_v1_datasets_id_files_bulk_load_tag import ApiRepositoryV1DatasetsIdFilesBulkLoadTag
from data_repo_client.apis.paths.api_repository_v1_datasets_id_files_bulk_array import ApiRepositoryV1DatasetsIdFilesBulkArray
from data_repo_client.apis.paths.api_repository_v1_datasets_id_files_fileid import ApiRepositoryV1DatasetsIdFilesFileid
from data_repo_client.apis.paths.api_repository_v1_datasets_id_filesystem_objects import ApiRepositoryV1DatasetsIdFilesystemObjects
from data_repo_client.apis.paths.api_repository_v1_jobs import ApiRepositoryV1Jobs
from data_repo_client.apis.paths.api_repository_v1_jobs_id import ApiRepositoryV1JobsId
from data_repo_client.apis.paths.api_repository_v1_jobs_id_result import ApiRepositoryV1JobsIdResult
from data_repo_client.apis.paths.api_repository_v1_configs_name import ApiRepositoryV1ConfigsName
from data_repo_client.apis.paths.api_repository_v1_configs import ApiRepositoryV1Configs
from data_repo_client.apis.paths.api_repository_v1_configs_reset import ApiRepositoryV1ConfigsReset
from data_repo_client.apis.paths.api_repository_v1_upgrade import ApiRepositoryV1Upgrade
from data_repo_client.apis.paths.api_repository_v1_search_id_index import ApiRepositoryV1SearchIdIndex
from data_repo_client.apis.paths.api_repository_v1_search_query import ApiRepositoryV1SearchQuery
from data_repo_client.apis.paths.ga4gh_drs_v1_service_info import Ga4ghDrsV1ServiceInfo
from data_repo_client.apis.paths.ga4gh_drs_v1_objects_object_id import Ga4ghDrsV1ObjectsObjectId
from data_repo_client.apis.paths.ga4gh_drs_v1_objects_object_id_access_access_id import Ga4ghDrsV1ObjectsObjectIdAccessAccessId
from data_repo_client.apis.paths.api_repository_v1_journal_resource_key import ApiRepositoryV1JournalResourceKey

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.STATUS: Status,
        PathValues.CONFIGURATION: Configuration,
        PathValues.SHUTDOWN: Shutdown,
        PathValues.API_RESOURCES_V1_PROFILES: ApiResourcesV1Profiles,
        PathValues.API_RESOURCES_V1_PROFILES_ID: ApiResourcesV1ProfilesId,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES: ApiResourcesV1ProfilesIdPolicies,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS: ApiResourcesV1ProfilesIdPoliciesPolicyNameMembers,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiResourcesV1ProfilesIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS: ApiRepositoryV1Snapshots,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ROLE_MAP: ApiRepositoryV1SnapshotsRoleMap,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID: ApiRepositoryV1SnapshotsId,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_SUMMARY: ApiRepositoryV1SnapshotsIdSummary,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_DATA_TABLE: ApiRepositoryV1SnapshotsIdDataTable,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_EXPORT: ApiRepositoryV1SnapshotsIdExport,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_FILES_FILEID: ApiRepositoryV1SnapshotsIdFilesFileid,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_FILESYSTEM_OBJECTS: ApiRepositoryV1SnapshotsIdFilesystemObjects,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES: ApiRepositoryV1SnapshotsIdPolicies,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS: ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembers,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_ROLES: ApiRepositoryV1SnapshotsIdRoles,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_LINK_DUOS_DATASET_DUOS_ID: ApiRepositoryV1SnapshotsIdLinkDuosDatasetDuosId,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_UNLINK_DUOS_DATASET: ApiRepositoryV1SnapshotsIdUnlinkDuosDataset,
        PathValues.API_REPOSITORY_V1_DUOS: ApiRepositoryV1Duos,
        PathValues.API_REPOSITORY_V1_DUOS_DUOS_ID: ApiRepositoryV1DuosDuosId,
        PathValues.API_REPOSITORY_V1_DUOS_DUOS_ID_SYNC_AUTHORIZED_USERS: ApiRepositoryV1DuosDuosIdSyncAuthorizedUsers,
        PathValues.API_REPOSITORY_V1_DATASETS: ApiRepositoryV1Datasets,
        PathValues.API_REPOSITORY_V1_DATASETS_ID: ApiRepositoryV1DatasetsId,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_SUMMARY: ApiRepositoryV1DatasetsIdSummary,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES: ApiRepositoryV1DatasetsIdPolicies,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS: ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembers,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ROLES: ApiRepositoryV1DatasetsIdRoles,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_INGEST: ApiRepositoryV1DatasetsIdIngest,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_UPDATE_SCHEMA: ApiRepositoryV1DatasetsIdUpdateSchema,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS: ApiRepositoryV1DatasetsIdTransactions,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS_TRANSACTION_ID: ApiRepositoryV1DatasetsIdTransactionsTransactionId,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ASSETS: ApiRepositoryV1DatasetsIdAssets,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ASSETS_ASSETID: ApiRepositoryV1DatasetsIdAssetsAssetid,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_DELETES: ApiRepositoryV1DatasetsIdDeletes,
        PathValues.API_REPOSITORY_V1_REGISTER_USER: ApiRepositoryV1RegisterUser,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES: ApiRepositoryV1DatasetsIdFiles,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK: ApiRepositoryV1DatasetsIdFilesBulk,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_LOAD_TAG: ApiRepositoryV1DatasetsIdFilesBulkLoadTag,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_ARRAY: ApiRepositoryV1DatasetsIdFilesBulkArray,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_FILEID: ApiRepositoryV1DatasetsIdFilesFileid,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILESYSTEM_OBJECTS: ApiRepositoryV1DatasetsIdFilesystemObjects,
        PathValues.API_REPOSITORY_V1_JOBS: ApiRepositoryV1Jobs,
        PathValues.API_REPOSITORY_V1_JOBS_ID: ApiRepositoryV1JobsId,
        PathValues.API_REPOSITORY_V1_JOBS_ID_RESULT: ApiRepositoryV1JobsIdResult,
        PathValues.API_REPOSITORY_V1_CONFIGS_NAME: ApiRepositoryV1ConfigsName,
        PathValues.API_REPOSITORY_V1_CONFIGS: ApiRepositoryV1Configs,
        PathValues.API_REPOSITORY_V1_CONFIGS_RESET: ApiRepositoryV1ConfigsReset,
        PathValues.API_REPOSITORY_V1_UPGRADE: ApiRepositoryV1Upgrade,
        PathValues.API_REPOSITORY_V1_SEARCH_ID_INDEX: ApiRepositoryV1SearchIdIndex,
        PathValues.API_REPOSITORY_V1_SEARCH_QUERY: ApiRepositoryV1SearchQuery,
        PathValues.GA4GH_DRS_V1_SERVICEINFO: Ga4ghDrsV1ServiceInfo,
        PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID: Ga4ghDrsV1ObjectsObjectId,
        PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID_ACCESS_ACCESS_ID: Ga4ghDrsV1ObjectsObjectIdAccessAccessId,
        PathValues.API_REPOSITORY_V1_JOURNAL_RESOURCE_KEY: ApiRepositoryV1JournalResourceKey,
    }
)

path_to_api = PathToApi(
    {
        PathValues.STATUS: Status,
        PathValues.CONFIGURATION: Configuration,
        PathValues.SHUTDOWN: Shutdown,
        PathValues.API_RESOURCES_V1_PROFILES: ApiResourcesV1Profiles,
        PathValues.API_RESOURCES_V1_PROFILES_ID: ApiResourcesV1ProfilesId,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES: ApiResourcesV1ProfilesIdPolicies,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS: ApiResourcesV1ProfilesIdPoliciesPolicyNameMembers,
        PathValues.API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiResourcesV1ProfilesIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS: ApiRepositoryV1Snapshots,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ROLE_MAP: ApiRepositoryV1SnapshotsRoleMap,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID: ApiRepositoryV1SnapshotsId,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_SUMMARY: ApiRepositoryV1SnapshotsIdSummary,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_DATA_TABLE: ApiRepositoryV1SnapshotsIdDataTable,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_EXPORT: ApiRepositoryV1SnapshotsIdExport,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_FILES_FILEID: ApiRepositoryV1SnapshotsIdFilesFileid,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_FILESYSTEM_OBJECTS: ApiRepositoryV1SnapshotsIdFilesystemObjects,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES: ApiRepositoryV1SnapshotsIdPolicies,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS: ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembers,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_ROLES: ApiRepositoryV1SnapshotsIdRoles,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_LINK_DUOS_DATASET_DUOS_ID: ApiRepositoryV1SnapshotsIdLinkDuosDatasetDuosId,
        PathValues.API_REPOSITORY_V1_SNAPSHOTS_ID_UNLINK_DUOS_DATASET: ApiRepositoryV1SnapshotsIdUnlinkDuosDataset,
        PathValues.API_REPOSITORY_V1_DUOS: ApiRepositoryV1Duos,
        PathValues.API_REPOSITORY_V1_DUOS_DUOS_ID: ApiRepositoryV1DuosDuosId,
        PathValues.API_REPOSITORY_V1_DUOS_DUOS_ID_SYNC_AUTHORIZED_USERS: ApiRepositoryV1DuosDuosIdSyncAuthorizedUsers,
        PathValues.API_REPOSITORY_V1_DATASETS: ApiRepositoryV1Datasets,
        PathValues.API_REPOSITORY_V1_DATASETS_ID: ApiRepositoryV1DatasetsId,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_SUMMARY: ApiRepositoryV1DatasetsIdSummary,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES: ApiRepositoryV1DatasetsIdPolicies,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS: ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembers,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL: ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembersMemberEmail,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ROLES: ApiRepositoryV1DatasetsIdRoles,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_INGEST: ApiRepositoryV1DatasetsIdIngest,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_UPDATE_SCHEMA: ApiRepositoryV1DatasetsIdUpdateSchema,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS: ApiRepositoryV1DatasetsIdTransactions,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS_TRANSACTION_ID: ApiRepositoryV1DatasetsIdTransactionsTransactionId,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ASSETS: ApiRepositoryV1DatasetsIdAssets,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_ASSETS_ASSETID: ApiRepositoryV1DatasetsIdAssetsAssetid,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_DELETES: ApiRepositoryV1DatasetsIdDeletes,
        PathValues.API_REPOSITORY_V1_REGISTER_USER: ApiRepositoryV1RegisterUser,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES: ApiRepositoryV1DatasetsIdFiles,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK: ApiRepositoryV1DatasetsIdFilesBulk,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_LOAD_TAG: ApiRepositoryV1DatasetsIdFilesBulkLoadTag,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_ARRAY: ApiRepositoryV1DatasetsIdFilesBulkArray,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILES_FILEID: ApiRepositoryV1DatasetsIdFilesFileid,
        PathValues.API_REPOSITORY_V1_DATASETS_ID_FILESYSTEM_OBJECTS: ApiRepositoryV1DatasetsIdFilesystemObjects,
        PathValues.API_REPOSITORY_V1_JOBS: ApiRepositoryV1Jobs,
        PathValues.API_REPOSITORY_V1_JOBS_ID: ApiRepositoryV1JobsId,
        PathValues.API_REPOSITORY_V1_JOBS_ID_RESULT: ApiRepositoryV1JobsIdResult,
        PathValues.API_REPOSITORY_V1_CONFIGS_NAME: ApiRepositoryV1ConfigsName,
        PathValues.API_REPOSITORY_V1_CONFIGS: ApiRepositoryV1Configs,
        PathValues.API_REPOSITORY_V1_CONFIGS_RESET: ApiRepositoryV1ConfigsReset,
        PathValues.API_REPOSITORY_V1_UPGRADE: ApiRepositoryV1Upgrade,
        PathValues.API_REPOSITORY_V1_SEARCH_ID_INDEX: ApiRepositoryV1SearchIdIndex,
        PathValues.API_REPOSITORY_V1_SEARCH_QUERY: ApiRepositoryV1SearchQuery,
        PathValues.GA4GH_DRS_V1_SERVICEINFO: Ga4ghDrsV1ServiceInfo,
        PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID: Ga4ghDrsV1ObjectsObjectId,
        PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID_ACCESS_ACCESS_ID: Ga4ghDrsV1ObjectsObjectIdAccessAccessId,
        PathValues.API_REPOSITORY_V1_JOURNAL_RESOURCE_KEY: ApiRepositoryV1JournalResourceKey,
    }
)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    DATA_REPOSITORY_SERVICE = "DataRepositoryService"
    CONFIGS = "configs"
    REPOSITORY = "repository"
    DATASETS = "datasets"
    DUOS = "duos"
    JOBS = "jobs"
    JOURNAL = "journal"
    PROFILES = "profiles"
    RESOURCES = "resources"
    REGISTER = "register"
    SNAPSHOTS = "snapshots"
    SEARCH = "search"
    UPGRADE = "upgrade"
    UNAUTHENTICATED = "unauthenticated"



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.paths.api_repository_v1_journal_resource_key import Api

from data_repo_client.paths import PathValues

path = PathValues.API_REPOSITORY_V1_JOURNAL_RESOURCE_KEY


# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    STATUS = "/status"
    CONFIGURATION = "/configuration"
    SHUTDOWN = "/shutdown"
    API_RESOURCES_V1_PROFILES = "/api/resources/v1/profiles"
    API_RESOURCES_V1_PROFILES_ID = "/api/resources/v1/profiles/{id}"
    API_RESOURCES_V1_PROFILES_ID_POLICIES = "/api/resources/v1/profiles/{id}/policies"
    API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS = "/api/resources/v1/profiles/{id}/policies/{policyName}/members"
    API_RESOURCES_V1_PROFILES_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL = "/api/resources/v1/profiles/{id}/policies/{policyName}/members/{memberEmail}"
    API_REPOSITORY_V1_SNAPSHOTS = "/api/repository/v1/snapshots"
    API_REPOSITORY_V1_SNAPSHOTS_ROLE_MAP = "/api/repository/v1/snapshots/roleMap"
    API_REPOSITORY_V1_SNAPSHOTS_ID = "/api/repository/v1/snapshots/{id}"
    API_REPOSITORY_V1_SNAPSHOTS_ID_SUMMARY = "/api/repository/v1/snapshots/{id}/summary"
    API_REPOSITORY_V1_SNAPSHOTS_ID_DATA_TABLE = "/api/repository/v1/snapshots/{id}/data/{table}"
    API_REPOSITORY_V1_SNAPSHOTS_ID_EXPORT = "/api/repository/v1/snapshots/{id}/export"
    API_REPOSITORY_V1_SNAPSHOTS_ID_FILES_FILEID = "/api/repository/v1/snapshots/{id}/files/{fileid}"
    API_REPOSITORY_V1_SNAPSHOTS_ID_FILESYSTEM_OBJECTS = "/api/repository/v1/snapshots/{id}/filesystem/objects"
    API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES = "/api/repository/v1/snapshots/{id}/policies"
    API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS = "/api/repository/v1/snapshots/{id}/policies/{policyName}/members"
    API_REPOSITORY_V1_SNAPSHOTS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL = "/api/repository/v1/snapshots/{id}/policies/{policyName}/members/{memberEmail}"
    API_REPOSITORY_V1_SNAPSHOTS_ID_ROLES = "/api/repository/v1/snapshots/{id}/roles"
    API_REPOSITORY_V1_SNAPSHOTS_ID_LINK_DUOS_DATASET_DUOS_ID = "/api/repository/v1/snapshots/{id}/linkDuosDataset/{duosId}"
    API_REPOSITORY_V1_SNAPSHOTS_ID_UNLINK_DUOS_DATASET = "/api/repository/v1/snapshots/{id}/unlinkDuosDataset"
    API_REPOSITORY_V1_DUOS = "/api/repository/v1/duos"
    API_REPOSITORY_V1_DUOS_DUOS_ID = "/api/repository/v1/duos/{duosId}"
    API_REPOSITORY_V1_DUOS_DUOS_ID_SYNC_AUTHORIZED_USERS = "/api/repository/v1/duos/{duosId}/syncAuthorizedUsers"
    API_REPOSITORY_V1_DATASETS = "/api/repository/v1/datasets"
    API_REPOSITORY_V1_DATASETS_ID = "/api/repository/v1/datasets/{id}"
    API_REPOSITORY_V1_DATASETS_ID_SUMMARY = "/api/repository/v1/datasets/{id}/summary"
    API_REPOSITORY_V1_DATASETS_ID_POLICIES = "/api/repository/v1/datasets/{id}/policies"
    API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS = "/api/repository/v1/datasets/{id}/policies/{policyName}/members"
    API_REPOSITORY_V1_DATASETS_ID_POLICIES_POLICY_NAME_MEMBERS_MEMBER_EMAIL = "/api/repository/v1/datasets/{id}/policies/{policyName}/members/{memberEmail}"
    API_REPOSITORY_V1_DATASETS_ID_ROLES = "/api/repository/v1/datasets/{id}/roles"
    API_REPOSITORY_V1_DATASETS_ID_INGEST = "/api/repository/v1/datasets/{id}/ingest"
    API_REPOSITORY_V1_DATASETS_ID_UPDATE_SCHEMA = "/api/repository/v1/datasets/{id}/updateSchema"
    API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS = "/api/repository/v1/datasets/{id}/transactions"
    API_REPOSITORY_V1_DATASETS_ID_TRANSACTIONS_TRANSACTION_ID = "/api/repository/v1/datasets/{id}/transactions/{transactionId}"
    API_REPOSITORY_V1_DATASETS_ID_ASSETS = "/api/repository/v1/datasets/{id}/assets"
    API_REPOSITORY_V1_DATASETS_ID_ASSETS_ASSETID = "/api/repository/v1/datasets/{id}/assets/{assetid}"
    API_REPOSITORY_V1_DATASETS_ID_DELETES = "/api/repository/v1/datasets/{id}/deletes"
    API_REPOSITORY_V1_REGISTER_USER = "/api/repository/v1/register/user"
    API_REPOSITORY_V1_DATASETS_ID_FILES = "/api/repository/v1/datasets/{id}/files"
    API_REPOSITORY_V1_DATASETS_ID_FILES_BULK = "/api/repository/v1/datasets/{id}/files/bulk"
    API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_LOAD_TAG = "/api/repository/v1/datasets/{id}/files/bulk/{loadTag}"
    API_REPOSITORY_V1_DATASETS_ID_FILES_BULK_ARRAY = "/api/repository/v1/datasets/{id}/files/bulk/array"
    API_REPOSITORY_V1_DATASETS_ID_FILES_FILEID = "/api/repository/v1/datasets/{id}/files/{fileid}"
    API_REPOSITORY_V1_DATASETS_ID_FILESYSTEM_OBJECTS = "/api/repository/v1/datasets/{id}/filesystem/objects"
    API_REPOSITORY_V1_JOBS = "/api/repository/v1/jobs"
    API_REPOSITORY_V1_JOBS_ID = "/api/repository/v1/jobs/{id}"
    API_REPOSITORY_V1_JOBS_ID_RESULT = "/api/repository/v1/jobs/{id}/result"
    API_REPOSITORY_V1_CONFIGS_NAME = "/api/repository/v1/configs/{name}"
    API_REPOSITORY_V1_CONFIGS = "/api/repository/v1/configs"
    API_REPOSITORY_V1_CONFIGS_RESET = "/api/repository/v1/configs/reset"
    API_REPOSITORY_V1_UPGRADE = "/api/repository/v1/upgrade"
    API_REPOSITORY_V1_SEARCH_ID_INDEX = "/api/repository/v1/search/{id}/index"
    API_REPOSITORY_V1_SEARCH_QUERY = "/api/repository/v1/search/query"
    GA4GH_DRS_V1_SERVICEINFO = "/ga4gh/drs/v1/service-info"
    GA4GH_DRS_V1_OBJECTS_OBJECT_ID = "/ga4gh/drs/v1/objects/{object_id}"
    GA4GH_DRS_V1_OBJECTS_OBJECT_ID_ACCESS_ACCESS_ID = "/ga4gh/drs/v1/objects/{object_id}/access/{access_id}"
    API_REPOSITORY_V1_JOURNAL_RESOURCE_KEY = "/api/repository/v1/journal/{resourceKey}"



from data_repo_client.paths.api_repository_v1_datasets_id_policies_policy_name_members_member_email.delete import ApiFordelete


class ApiRepositoryV1DatasetsIdPoliciesPolicyNameMembersMemberEmail(
    ApiFordelete,
):
    pass



from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.get import ApiForget
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.post import ApiForpost
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id.options import ApiForoptions


class Ga4ghDrsV1ObjectsObjectId(
    ApiForget,
    ApiForpost,
    ApiForoptions,
):
    pass



from data_repo_client.paths.api_resources_v1_profiles_id_policies_policy_name_members_member_email.delete import ApiFordelete


class ApiResourcesV1ProfilesIdPoliciesPolicyNameMembersMemberEmail(
    ApiFordelete,
):
    pass



from data_repo_client.paths.api_repository_v1_datasets.get import ApiForget
from data_repo_client.paths.api_repository_v1_datasets.post import ApiForpost


class ApiRepositoryV1Datasets(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from data_repo_client import schemas  # noqa: F401


class ConfigEnableModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Control whether a fault is enabled
    """


    class MetaOapg:
        
        class properties:
            enabled = schemas.BoolSchema
            __annotations__ = {
                "enabled": enabled,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["enabled", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> typing.Union[MetaOapg.properties.enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["enabled", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        enabled: typing.Union[MetaOapg.properties.enabled, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ConfigEnableModel':
        return super().__new__(
            cls,
            *_args,
            enabled=enabled,
            _configuration=_configuration,
            **kwargs,
        )



from data_repo_client.paths.api_repository_v1_snapshots_id_policies_policy_name_members.post import ApiForpost


class ApiRepositoryV1SnapshotsIdPoliciesPolicyNameMembers(
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

import logging
import ssl
from urllib.parse import urlencode
import typing

import certifi
import urllib3
from urllib3._collections import HTTPHeaderDict

from data_repo_client.exceptions import ApiException, ApiValueError


logger = logging.getLogger(__name__)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args['retries'] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args['socket_options'] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(
        self,
        method: str,
        url: str,
        headers: typing.Optional[HTTPHeaderDict] = None,
        fields: typing.Optional[typing.Tuple[typing.Tuple[str, typing.Any], ...]] = None,
        body: typing.Optional[typing.Union[str, bytes]] = None,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> urllib3.HTTPResponse:
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param headers: http request headers
        :param body: request body, for other types
        :param fields: request parameters for
                                `application/x-www-form-urlencoded`
                                or `multipart/form-data`
        :param stream: if True, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is False.
        :param timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if fields and body:
            raise ApiValueError(
                "body parameter cannot be used with fields parameter."
            )

        fields = fields or {}
        headers = headers or {}

        if timeout:
            if isinstance(timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=timeout)
            elif (isinstance(timeout, tuple) and
                  len(timeout) == 2):
                timeout = urllib3.Timeout(connect=timeout[0], read=timeout[1])

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if 'Content-Type' not in headers and body is None:
                    r = self.pool_manager.request(
                        method,
                        url,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers
                    )
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        body=body,
                        fields=fields,
                        encode_multipart=False,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=fields,
                        encode_multipart=True,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              preload_content=not stream,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if not stream:
            # log response body
            logger.debug("response body: %s", r.data)

        return r

    def GET(self, url, headers=None, stream=False,
            timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("GET", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def HEAD(self, url, headers=None, stream=False,
             timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("HEAD", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def OPTIONS(self, url, headers=None,
                body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("OPTIONS", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def DELETE(self, url, headers=None, body=None,
               stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("DELETE", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def POST(self, url, headers=None,
             body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("POST", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PUT(self, url, headers=None,
            body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PUT", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PATCH(self, url, headers=None,
              body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PATCH", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)



from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id.get import ApiForget
from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id.post import ApiForpost


class Ga4ghDrsV1ObjectsObjectIdAccessAccessId(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from data_repo_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from data_repo_client import schemas  # noqa: F401

from data_repo_client.model.snapshot_retrieve_include_model import SnapshotRetrieveIncludeModel
from data_repo_client.model.snapshot_model import SnapshotModel
from data_repo_client.model.error_model import ErrorModel

from . import path

# Query params


class IncludeSchema(
    schemas.ListSchema
):


    class MetaOapg:
        
        @staticmethod
        def items() -> typing.Type['SnapshotRetrieveIncludeModel']:
            return SnapshotRetrieveIncludeModel

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple['SnapshotRetrieveIncludeModel'], typing.List['SnapshotRetrieveIncludeModel']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'IncludeSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'SnapshotRetrieveIncludeModel':
        return super().__getitem__(i)
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'include': typing.Union[IncludeSchema, list, tuple, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_include = api_client.QueryParameter(
    name="include",
    style=api_client.ParameterStyle.FORM,
    schema=IncludeSchema,
    explode=True,
)
# Path params
IdSchema = schemas.UUIDSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'id': typing.Union[IdSchema, str, uuid.UUID, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_id = api_client.PathParameter(
    name="id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=IdSchema,
    required=True,
)
_auth = [
    'googleoauth',
    'oidc',
]
SchemaFor200ResponseBodyApplicationJson = SnapshotModel


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor400ResponseBodyApplicationJson = ErrorModel


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)
SchemaFor403ResponseBodyApplicationJson = ErrorModel


@dataclass
class ApiResponseFor403(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor403ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_403 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor403,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor403ResponseBodyApplicationJson),
    },
)
SchemaFor404ResponseBodyApplicationJson = ErrorModel


@dataclass
class ApiResponseFor404(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor404ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_404 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor404,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor404ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '403': _response_for_403,
    '404': _response_for_404,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _retrieve_snapshot_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _retrieve_snapshot_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _retrieve_snapshot_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _retrieve_snapshot_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        prefix_separator_iterator = None
        for parameter in (
            request_query_include,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class RetrieveSnapshot(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def retrieve_snapshot(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def retrieve_snapshot(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def retrieve_snapshot(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def retrieve_snapshot(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._retrieve_snapshot_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._retrieve_snapshot_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from data_repo_client.paths.api_repository_v1_datasets_id.get import ApiForget
from data_repo_client.paths.api_repository_v1_datasets_id.delete import ApiFordelete
from data_repo_client.paths.api_repository_v1_datasets_id.patch import ApiForpatch


class ApiRepositoryV1DatasetsId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



from data_repo_client.paths.api_repository_v1_datasets_id_files_fileid.get import ApiForget
from data_repo_client.paths.api_repository_v1_datasets_id_files_fileid.delete import ApiFordelete


class ApiRepositoryV1DatasetsIdFilesFileid(
    ApiForget,
    ApiFordelete,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from data_repo_client.paths.ga4gh_drs_v1_objects_object_id_access_access_id import Api

from data_repo_client.paths import PathValues

path = PathValues.GA4GH_DRS_V1_OBJECTS_OBJECT_ID_ACCESS_ACCESS_ID


# coding: utf-8

# flake8: noqa

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.443.0"

# import ApiClient
from data_repo_client.api_client import ApiClient

# import Configuration
from data_repo_client.configuration import Configuration

# import exceptions
from data_repo_client.exceptions import OpenApiException
from data_repo_client.exceptions import ApiAttributeError
from data_repo_client.exceptions import ApiTypeError
from data_repo_client.exceptions import ApiValueError
from data_repo_client.exceptions import ApiKeyError
from data_repo_client.exceptions import ApiException



from data_repo_client.paths.api_repository_v1_configs_name.get import ApiForget
from data_repo_client.paths.api_repository_v1_configs_name.put import ApiForput


class ApiRepositoryV1ConfigsName(
    ApiForget,
    ApiForput,
):
    pass



from data_repo_client.paths.api_resources_v1_profiles_id.get import ApiForget
from data_repo_client.paths.api_resources_v1_profiles_id.delete import ApiFordelete


class ApiResourcesV1ProfilesId(
    ApiForget,
    ApiFordelete,
):
    pass



from data_repo_client.paths.api_resources_v1_profiles.get import ApiForget
from data_repo_client.paths.api_resources_v1_profiles.put import ApiForput
from data_repo_client.paths.api_resources_v1_profiles.post import ApiForpost


class ApiResourcesV1Profiles(
    ApiForget,
    ApiForput,
    ApiForpost,
):
    pass



import typing_extensions

from data_repo_client.apis.tags import TagValues
from data_repo_client.apis.tags.data_repository_service_api import DataRepositoryServiceApi
from data_repo_client.apis.tags.configs_api import ConfigsApi
from data_repo_client.apis.tags.repository_api import RepositoryApi
from data_repo_client.apis.tags.datasets_api import DatasetsApi
from data_repo_client.apis.tags.duos_api import DuosApi
from data_repo_client.apis.tags.jobs_api import JobsApi
from data_repo_client.apis.tags.journal_api import JournalApi
from data_repo_client.apis.tags.profiles_api import ProfilesApi
from data_repo_client.apis.tags.resources_api import ResourcesApi
from data_repo_client.apis.tags.register_api import RegisterApi
from data_repo_client.apis.tags.snapshots_api import SnapshotsApi
from data_repo_client.apis.tags.search_api import SearchApi
from data_repo_client.apis.tags.upgrade_api import UpgradeApi
from data_repo_client.apis.tags.unauthenticated_api import UnauthenticatedApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.DATA_REPOSITORY_SERVICE: DataRepositoryServiceApi,
        TagValues.CONFIGS: ConfigsApi,
        TagValues.REPOSITORY: RepositoryApi,
        TagValues.DATASETS: DatasetsApi,
        TagValues.DUOS: DuosApi,
        TagValues.JOBS: JobsApi,
        TagValues.JOURNAL: JournalApi,
        TagValues.PROFILES: ProfilesApi,
        TagValues.RESOURCES: ResourcesApi,
        TagValues.REGISTER: RegisterApi,
        TagValues.SNAPSHOTS: SnapshotsApi,
        TagValues.SEARCH: SearchApi,
        TagValues.UPGRADE: UpgradeApi,
        TagValues.UNAUTHENTICATED: UnauthenticatedApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.DATA_REPOSITORY_SERVICE: DataRepositoryServiceApi,
        TagValues.CONFIGS: ConfigsApi,
        TagValues.REPOSITORY: RepositoryApi,
        TagValues.DATASETS: DatasetsApi,
        TagValues.DUOS: DuosApi,
        TagValues.JOBS: JobsApi,
        TagValues.JOURNAL: JournalApi,
        TagValues.PROFILES: ProfilesApi,
        TagValues.RESOURCES: ResourcesApi,
        TagValues.REGISTER: RegisterApi,
        TagValues.SNAPSHOTS: SnapshotsApi,
        TagValues.SEARCH: SearchApi,
        TagValues.UPGRADE: UpgradeApi,
        TagValues.UNAUTHENTICATED: UnauthenticatedApi,
    }
)
